Coverage report

# Coverage report: 89.92%

Hot-keys on this page

n s m x b p c change column sorting

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 1347 | 110 | 12 | 230 | 25 | 89.92%
/home/tribaal/workspace/django-shop/shop/__init__ | 2 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/addressmodel/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/addressmodel/admin | 10 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/addressmodel/models | 34 | 3 | 0 | 0 | 0 | 91.18%
/home/tribaal/workspace/django-shop/shop/admin/__init__ | 1 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/admin/mixins | 12 | 7 | 0 | 6 | 0 | 27.78%
/home/tribaal/workspace/django-shop/shop/admin/orderadmin | 31 | 0 | 0 | 2 | 1 | 96.97%
/home/tribaal/workspace/django-shop/shop/backends_pool | 42 | 0 | 0 | 12 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/cart/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/cart/cart_modifiers_base | 23 | 0 | 0 | 4 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/cart/modifiers/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/cart/modifiers/rebate_modifiers | 11 | 0 | 0 | 2 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/cart/modifiers/tax_modifiers | 14 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/cart/modifiers_pool | 32 | 0 | 0 | 6 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/forms | 34 | 0 | 0 | 6 | 1 | 97.50%
/home/tribaal/workspace/django-shop/shop/models/__init__ | 7 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models/cartmodel | 7 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models/defaults/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models/defaults/bases | 1 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models/defaults/cart | 8 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models/defaults/cartitem | 8 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models/defaults/managers | 1 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models/defaults/order | 10 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models/defaults/orderitem | 8 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models/defaults/product | 11 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models/ordermodel | 52 | 4 | 0 | 4 | 1 | 87.50%
/home/tribaal/workspace/django-shop/shop/models/productmodel | 5 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/models_bases/__init__ | 211 | 2 | 0 | 34 | 4 | 97.55%
/home/tribaal/workspace/django-shop/shop/models_bases/managers | 69 | 8 | 0 | 10 | 1 | 86.08%
/home/tribaal/workspace/django-shop/shop/order_signals | 7 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/payment/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/payment/api | 24 | 2 | 0 | 2 | 1 | 88.46%
/home/tribaal/workspace/django-shop/shop/payment/backends/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/payment/backends/pay_on_delivery | 18 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/payment/urls | 9 | 0 | 0 | 2 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/shipping/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/shipping/api | 25 | 0 | 0 | 4 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/shipping/backends/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/shipping/backends/flat_rate | 26 | 3 | 0 | 0 | 0 | 88.46%
/home/tribaal/workspace/django-shop/shop/shipping/urls | 9 | 0 | 0 | 2 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/shop_api | 22 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/templatetags/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/templatetags/shop_tags | 36 | 7 | 0 | 4 | 0 | 77.50%
/home/tribaal/workspace/django-shop/shop/urls/__init__ | 3 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/urls/cart | 3 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/urls/catalog | 5 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/urls/checkout | 4 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/urls/order | 3 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/util/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/util/address | 42 | 4 | 0 | 16 | 2 | 86.21%
/home/tribaal/workspace/django-shop/shop/util/cart | 49 | 1 | 0 | 26 | 2 | 96.00%
/home/tribaal/workspace/django-shop/shop/util/decorators | 48 | 1 | 0 | 10 | 1 | 96.55%
/home/tribaal/workspace/django-shop/shop/util/fields | 7 | 0 | 6 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/util/loader | 52 | 17 | 0 | 14 | 1 | 66.67%
/home/tribaal/workspace/django-shop/shop/util/login_mixin | 29 | 5 | 0 | 12 | 3 | 80.49%
/home/tribaal/workspace/django-shop/shop/util/order | 25 | 0 | 0 | 12 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/views/__init__ | 6 | 0 | 6 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/views/cart | 82 | 6 | 0 | 10 | 3 | 90.22%
/home/tribaal/workspace/django-shop/shop/views/checkout | 139 | 39 | 0 | 28 | 3 | 71.26%
/home/tribaal/workspace/django-shop/shop/views/order | 20 | 0 | 0 | 0 | 0 | 100.00%
/home/tribaal/workspace/django-shop/shop/views/product | 10 | 1 | 0 | 2 | 1 | 83.33%